<?php
/**
 * Plugin Name: CryptoWoo Requirements Check
 * Plugin URI: http://www.cryptowoo.com
 * Description: This plugin checks if your WordPress installation is ready to use CryptoWoo.
 * Version: 1.2
 * Author: flxstn
 * Author URI: https://www.cryptowoo.com
 * License: GPL2
 */

define('CWREQ_PATH', plugins_url(basename(plugin_dir_path(__FILE__)), basename(__FILE__)) . '/');

/* Redirect the user to the plugin page after installation */
register_activation_hook(__FILE__, 'cryptowoo_plugin_req_activate');
add_action('admin_init', 'cryptowoo_plugin_req_redirect');

function cryptowoo_plugin_req_activate() {
	add_option('cryptowoo_plugin_req_do_activation_redirect', true);
}

function cryptowoo_plugin_req_redirect() {
	if (get_option('cryptowoo_plugin_req_do_activation_redirect', false)) {
		delete_option('cryptowoo_plugin_req_do_activation_redirect');
		wp_redirect(get_site_url() . '/wp-admin/admin.php?page=cryptowoo-req');

	}
}

function cryptowoo_req_enqueue() {

	wp_enqueue_style('cryptowoo-plugin-fa', CWREQ_PATH.'css/font-awesome-4.2.0/css/font-awesome.min.css', 'cryptowoo-fa');
	wp_enqueue_style('cryptowoo-plugin-req', CWREQ_PATH.'css/style.css', 'cryptowoo-req');

}
add_action( 'admin_enqueue_scripts', 'cryptowoo_req_enqueue' );


add_action('admin_menu', 'cryptowoo_req_plugin_menu');

function cryptowoo_req_plugin_menu() {
    add_menu_page (
        'CryptoWoo - Cryptocurrency Payment Plugin Requirements Check', // Page title
        'CryptoWoo Requirements',                        // Menu Title - lower corner of admin menu
         'manage_options',                          // Capability
        'cryptowoo-req',                                  // Handle - First submenu's handle must be equal to parent's handle to avoid duplicate menu entry.
        'cryptowoo_req_options',                   // Function
        CWREQ_PATH.'img/cryptowoo.png'              // Icon URL
             );
}

define('CW_PHP_REQUIRED',  '5.6.0');

function cw_req_get_issues() {
	$issues = null;

	if (version_compare(PHP_VERSION, CW_PHP_REQUIRED, '<')) {
		$issues .= sprintf(__('Your current %sPHP Version is %s%s You need at least %s%s', 'cryptowoo'), '<b>', phpversion(), '</b>.',  CW_PHP_REQUIRED, '<br>');
	}
	if (!class_exists( 'woocommerce' )) {
		$issues .= '<li><i class="fa fa-exclamation"></i> <a href="https://wordpress.org/plugins/woocommerce/" target="_blank">WooCommere</a> seems to be deactivated or not installed.</li>';
	}
	if (!extension_loaded('curl')) {
		$issues .= '<li><i class="fa fa-exclamation"></i> <a href="http://php.net/manual/en/curl.installation.php" target="_blank">cURL</a> PHP extension not found</li>';
	}
	if (!extension_loaded('gmp')) {
		$issues .= '<li><i class="fa fa-exclamation"></i> <a href="http://php.net/manual/en/gmp.installation.php" target="_blank">GMP</a> PHP extension not found</li>';
	}
	return $issues;
}

function cryptowoo_req_options() {
	if ( !current_user_can( 'manage_options' ) )  {
		wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
	} ?>
	<div class="wrap">
        <a title="Go to www.cryptowoo.com" target="_blank" href="https://www.cryptowoo.com/?ref=cw-req"><img src="<?php echo plugins_url('img/logo.png', __FILE__); ?>" alt="CryptoWoo Logo" /></a>
            <h1>CryptoWoo Plugin Requirements Check</h1>
<?php if(null === ($issues = cw_req_get_issues())) { ?>
        <p><i class="fa fa-check-square-o fa-2x blueiconcolor"></i> <span class="success">Success!</span> Your server is ready to use CryptoWoo!</p>
        <p><a class="button-primary" target="_blank" title="Go to www.cryptowoo.com" href="https://www.cryptowoo.com/pricing/?ref=cw-req">Buy now!</a></p>
     <?php  } else { ?>
     <p><span class="fail">Failed!</span> Your Server is not yet ready to use CryptoWoo!</p>
     <p>Please fix the following issues:</p>
     <div class="issues">
        <ul>
		<?php echo $issues; ?>
		</ul>
    </div>
    <p>Are you experiencing other problems than those listed above? <br>
    Contact us and we will get back to you as soon as possible!</p>
    <div class="btn-group">
       <a  class="btn btn-default" title="CryptoWoo Support" href="http://www.cryptowoo.com/support/?ref=cw-req" target="_blank">
          <span class="fa-stack fa-3x">
             <i class="fa fa-circle fa-stack-2x blueiconcolor"></i>
             <i class="fa fa-life-saver fa-stack-1x whiteiconcolor"></i>
          </span>
       </a>
       <a  class="btn btn-default" title="e-Mail" href="mailto:support@cryptowoo.com">
          <span  class="fa-stack fa-3x">
             <i class="fa fa-circle fa-stack-2x blueiconcolor"></i>
             <i class="fa fa-envelope-o fa-stack-1x whiteiconcolor"></i>
          </span>
       </a>
    </div>
	<?php  } ?>
	</div><div align="bottom" class="footer"><a class="footer" target="_blank" href="https://www.cryptowoo.com/?ref=cw-req">CryptoWoo</a> - accept digital currencies in your WordPress based webshop!</div>
<?php } ?>
